@@ -1,7 +1,7 @@
 """
 Type annotations for iot1click-devices service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/literals/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/literals/)
 
 Usage::
 
@@ -252,6 +252,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
